package com.ff.common.service;

import java.util.List;
import com.ff.common.domain.TenantGameQuota;
import com.ff.common.dto.BalanceChangesDTO;

/**
 * 租户游戏配额Service接口
 * 
 * @author shi
 * @date 2025-02-12
 */
public interface ITenantGameQuotaService 
{
    /**
     * 查询租户游戏配额
     * 
     * @param id 租户游戏配额主键
     * @return 租户游戏配额
     */
     TenantGameQuota selectTenantGameQuotaById(Long id);

    /**
     * 查询租户游戏配额列表
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 租户游戏配额集合
     */
     List<TenantGameQuota> selectTenantGameQuotaList(TenantGameQuota tenantGameQuota);

    /**
     * 新增租户游戏配额
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 结果
     */
     int insertTenantGameQuota(TenantGameQuota tenantGameQuota);

    /**
     * 修改租户游戏配额
     * 
     * @param tenantGameQuota 租户游戏配额
     * @return 结果
     */
     int updateTenantGameQuota(TenantGameQuota tenantGameQuota);

    /**
     * 批量删除租户游戏配额
     * 
     * @param ids 需要删除的租户游戏配额主键集合
     * @return 结果
     */
     int deleteTenantGameQuotaByIds(Long[] ids);

    /**
     * 删除租户游戏配额信息
     * 
     * @param id 租户游戏配额主键
     * @return 结果
     */
     int deleteTenantGameQuotaById(Long id);

    /**
     * 余额变化
     *
     * @param balanceChangesDTO 余额更改为
     * @return {@link Boolean }
     */
    Boolean balanceChanges(BalanceChangesDTO balanceChangesDTO);
}
